- algorithm
character for the algorithm used to estimate the
distribution of cell type abundance among : 'Cibersort', 'Cibersort_ABS',
'EPIC', 'MCP_counter', 'Quantiseq', 'Timer', 'Xcell', 'Xcell (2)' and
'Xcell64'.
- disease
character for the type of TCGA cancer (see the list in
extdata/disease_names.csv).
- tissue
character for the type of TCGA tissue among :
'Additional - New Primary',
'Additional Metastatic',
'Metastatic',
'Primary Blood Derived Cancer - Peripheral Blood',
'Primary Tumor',
'Recurrent Tumor',
'Solid Tissue Normal'
- gene_x
character for the gene selected in the differential analysis
(see the list in extdata/gene_names.csv).
- stat
character for the statistic to be chosen among "mean", "median"
or "quantile".
- path
character for the path name of the tcga dataset.